LoginMethod class abstract

An abstract class that defines a method for logging in.

Implementers

Constructors

LoginMethod()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

login() Future<(UserCredential?, dynamic)>
Attempts to log in and returns a Future containing a tuple.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited